@@ -65,7 +65,6 @@ let offsetCollectionsController = null;
 let offsetDocumentsController = null;
 let offsetSearchController = null;
 let queryBuilder = null;
-let searchCategoryManager = null;
 let searchController = null;
 let searchMatchManager = null;
 let searchTypeManager = null;
@@ -482,58 +481,10 @@ const Application = new Lang.Class({
               callback: Lang.bind(this, this._onActionNightMode),
               create_hook: Lang.bind(this, this._nightModeCreateHook),
               state: settings.get_value('night-mode') },
-            { name: 'gear-menu',
-              callback: Utils.actionToggleCallback,
-              state: GLib.Variant.new('b', false),
-              accels: ['F10'] },
-            { name: 'view-as',
-              callback: Lang.bind(this, this._onActionViewAs),
-              create_hook: Lang.bind(this, this._viewAsCreateHook),
-              parameter_type: 's',
-              state: settings.get_value('view-as'),
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] },
-            { name: 'sort-by',
-              callback: Lang.bind(this, this._onActionSortBy),
-              create_hook: Lang.bind(this, this._sortByCreateHook),
-              parameter_type: 's',
-              state: settings.get_value('sort-by'),
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] },
-            { name: 'view-current',
-              window_mode: WindowMode.WindowMode.EDIT },
             { name: 'search',
               callback: Utils.actionToggleCallback,
               state: GLib.Variant.new('b', false),
-              accels: ['<Primary>f'] },
-            { name: 'select-all', accels: ['<Primary>a'],
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] },
-            { name: 'select-none',
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] },
-            { name: 'search-source',
-              parameter_type: 's',
-              state: GLib.Variant.new('s', Search.SearchSourceStock.ALL),
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] },
-            { name: 'search-type',
-              parameter_type: 's',
-              state: GLib.Variant.new('s', Search.SearchTypeStock.ALL),
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] },
-            { name: 'search-match',
-              parameter_type: 's',
-              state: GLib.Variant.new('s', Search.SearchMatchStock.ALL),
-              window_modes: [WindowMode.WindowMode.COLLECTIONS,
-                             WindowMode.WindowMode.DOCUMENTS,
-                             WindowMode.WindowMode.SEARCH] }
+              accels: ['<Primary>f'] }
         ];
 
         if (!this.isBooks)
