@@ -41,10 +41,10 @@ create_thumbnail (GIOSchedulerJob *job,
 {
   GSimpleAsyncResult *result = user_data;
   GFile *file = G_FILE (g_async_result_get_source_object (G_ASYNC_RESULT (result)));
-  GnomeDesktopThumbnailFactory *factory = NULL;
-  GFileInfo *info = NULL;
-  gchar *uri = NULL;
-  GdkPixbuf *pixbuf = NULL;
+  GnomeDesktopThumbnailFactory *factory;
+  GFileInfo *info;
+  gchar *uri;
+  GdkPixbuf *pixbuf;
   guint64 mtime;
 
   uri = g_file_get_uri (file);
@@ -79,15 +79,15 @@ create_thumbnail (GIOSchedulerJob *job,
       g_simple_async_result_set_op_res_gboolean (result, FALSE);
     }
 
+  g_object_unref (info);
+  g_object_unref (file);
+  g_object_unref (factory);
+  g_clear_object (&pixbuf);
+
  out:
   g_simple_async_result_complete_in_idle (result);
   g_object_unref (result);
 
-  g_clear_object (&info);
-  g_object_unref (file);
-  g_clear_object (&factory);
-  g_clear_object (&pixbuf);
-  g_free (uri);
   return FALSE;
 }
 
@@ -185,6 +185,10 @@ gd_filename_to_mime_type (const gchar *filename_with_extension)
 
   if (g_strcmp0 (extension, ".pdf") == 0)
     type = "application/pdf";
+  else if (g_strcmp0 (extension, ".djv") == 0)
+    type = "image/vnd.djvu+multipage";
+  else if (g_strcmp0 (extension, ".djvu") == 0)
+    type = "image/vnd.djvu+multipage";
   else if (g_strcmp0 (extension, ".epub") == 0)
     type = "application/epub+zip";
   else if (g_strcmp0 (extension, ".cbr") == 0)
@@ -235,6 +239,8 @@ gd_filename_to_rdf_type (const gchar *filename_with_extension)
     type = "nfo:PaginatedTextDocument";
 
   else if (g_strcmp0 (extension, ".epub") == 0
+           || g_strcmp0 (extension, ".djv") == 0
+           || g_strcmp0 (extension, ".djvu") == 0
            || g_strcmp0 (extension, ".cbr") == 0
            || g_strcmp0 (extension, ".cbz") == 0
            || g_strcmp0 (extension, ".cbt") == 0
