@@ -20,27 +20,21 @@
  *
  */
 
-const EvView = imports.gi.EvinceView;
-const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
-const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
 const _ = imports.gettext.gettext;
 const C_ = imports.gettext.pgettext;
 
 const Application = imports.application;
-const Documents = imports.documents;
 const Mainloop = imports.mainloop;
-const Manager = imports.manager;
 const Notifications = imports.notifications;
 const Properties = imports.properties;
 const Query = imports.query;
 const Sharing = imports.sharing;
 const TrackerUtils = imports.trackerUtils;
-const Utils = imports.utils;
 const WindowMode = imports.windowMode;
 
 const Lang = imports.lang;
@@ -952,7 +946,7 @@ const SelectionToolbar = new Lang.Class({
         let hasSelection = (selection.length > 0);
 
         let showTrash = hasSelection;
-        let showPrint = false;
+        let showPrint = hasSelection;
         let showProperties = hasSelection;
         let showOpen = hasSelection;
         let showShare = hasSelection;
@@ -973,21 +967,15 @@ const SelectionToolbar = new Lang.Class({
                     showShare = false;
 
                 showTrash &= doc.canTrash();
+                showPrint &= !doc.collection;
             }));
 
         showOpen = (apps.length > 0);
 
-        if (selection.length == 1) {
-            let doc = Application.documentManager.getItemById(selection[0]);
-            doc.load(null, null, Lang.bind(this,
-                function(doc, docModel, error) {
-                    showPrint = doc.canPrint(docModel);
-                    this._toolbarPrint.set_sensitive(showPrint);
-                }));
-        }
-
-        if (selection.length > 1)
+        if (selection.length > 1) {
+            showPrint = false;
             showProperties = false;
+        }
 
         let openLabel = null;
         if (apps.length == 1) {
