@@ -137,8 +137,7 @@ const TrackerController = new Lang.Class({
         this._offsetController = this.getOffsetController();
         this._offsetController.connect('offset-changed', Lang.bind(this, this._performCurrentQuery));
 
-        this._sortSettingsId = Application.application.connect('action-state-changed::sort-by',
-            Lang.bind(this, this._updateSortForSettings));
+        Application.settings.connect('changed::sort-by', Lang.bind(this, this._updateSortForSettings));
         this._updateSortForSettings();
     },
 
@@ -365,7 +364,6 @@ const TrackerSearchController = new Lang.Class({
 
         Application.sourceManager.connect('active-changed', Lang.bind(this, this.refreshForObject));
         Application.searchController.connect('search-string-changed', Lang.bind(this, this.refreshForObject));
-        Application.searchCategoryManager.connect('active-changed', Lang.bind(this, this.refreshForObject));
         Application.searchTypeManager.connect('active-changed', Lang.bind(this, this.refreshForObject));
 
         Application.searchMatchManager.connect('active-changed', Lang.bind(this, this._onSearchMatchChanged));
