@@ -377,6 +377,8 @@ const ViewContainer = new Lang.Class({
                           Lang.bind(this, this._onSelectionModeRequest));
         this.view.connect('view-selection-changed',
                           Lang.bind(this, this._onViewSelectionChanged));
+        this.view.connect('notify::view-type',
+                          Lang.bind(this, this._onViewTypeChanged));
 
         this._updateTypeForSettings();
         this._updateSortForSettings();
@@ -452,9 +454,6 @@ const ViewContainer = new Lang.Class({
     _updateTypeForSettings: function() {
         let viewType = Application.settings.get_enum('view-as');
         this.view.set_view_type(viewType);
-
-        if (viewType == Gd.MainViewType.LIST)
-            this._addListRenderers();
     },
 
     _updateSortForSettings: function() {
@@ -513,12 +512,6 @@ const ViewContainer = new Lang.Class({
         Application.searchMatchManager.setActiveItemById(itemId);
     },
 
-    _activateResult: function() {
-        let doc = this._getFirstDocument();
-        if (doc)
-            Application.documentManager.setActiveItem(doc)
-    },
-
     _getFirstDocument: function() {
         let doc = null;
 
@@ -531,6 +524,11 @@ const ViewContainer = new Lang.Class({
         return doc;
     },
 
+    _onViewTypeChanged: function() {
+        if (this.view.view_type == Gd.MainViewType.LIST)
+            this._addListRenderers();
+    },
+
     _addListRenderers: function() {
         let listWidget = this.view.get_generic_view();
 
@@ -719,11 +717,14 @@ const ViewContainer = new Lang.Class({
         }
     },
 
+    activateResult: function() {
+        let doc = this._getFirstDocument();
+        if (doc)
+            Application.documentManager.setActiveItem(doc)
+    },
+
     createToolbar: function(stack) {
-        let toolbar = new MainToolbar.OverviewToolbar(stack);
-        toolbar.searchbar.connectJS('activate-result',
-                                    Lang.bind(this, this._activateResult));
-        return toolbar;
+        return new MainToolbar.OverviewToolbar(stack);
     }
 });
 
@@ -755,14 +756,14 @@ const View = new Lang.Class({
         this._search = new ViewContainer(WindowMode.WindowMode.SEARCH);
         this._stack.add_named(this._search, 'search');
 
-        this.connect('notify::visible-child',
-                     Lang.bind(this, this._onVisibleChildChanged));
+        this._stack.connect('notify::visible-child',
+                            Lang.bind(this, this._onVisibleChildChanged));
 
         this.show();
     },
 
     _onVisibleChildChanged: function() {
-        let visibleChild = this.visible_child;
+        let visibleChild = this._stack.visible_child;
         let windowMode;
 
         if (visibleChild == this._collections)
@@ -807,6 +808,10 @@ const View = new Lang.Class({
         this._stack.add_named(this._preview, 'preview');
     },
 
+    activateResult: function() {
+        this.view.activateResult();
+    },
+
     createToolbar: function() {
         return this.view.createToolbar(this._stack);
     },
